@@ -3,12 +3,12 @@ package delete
 import (
 	"fmt"
 
-	"gitlab.com/gitlab-org/cli/internal/iostreams"
+	"github.com/spf13/cobra"
 
 	"gitlab.com/gitlab-org/cli/internal/cmdutils"
-
-	"github.com/spf13/cobra"
 	"gitlab.com/gitlab-org/cli/internal/config"
+	"gitlab.com/gitlab-org/cli/internal/iostreams"
+	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
 )
 
 type options struct {
@@ -28,6 +28,9 @@ func NewCmdDelete(f cmdutils.Factory) *cobra.Command {
 		Short: `Delete an alias.`,
 		Long:  ``,
 		Args:  cobra.ExactArgs(1),
+		Annotations: map[string]string{
+			mcpannotations.Destructive: "true",
+		},
 		RunE: func(cmd *cobra.Command, args []string) error {
 			opts.complete(args)
 
