@@ -8,10 +8,13 @@ import (
 
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
+	"go.uber.org/mock/gomock"
+
 	gitlab "gitlab.com/gitlab-org/api/client-go"
 	gitlabtesting "gitlab.com/gitlab-org/api/client-go/testing"
+
+	"gitlab.com/gitlab-org/cli/internal/commands/ci/ciutils"
 	"gitlab.com/gitlab-org/cli/internal/testing/cmdtest"
-	"go.uber.org/mock/gomock"
 )
 
 func Test_getPipelineWithFallback(t *testing.T) {
@@ -28,19 +31,60 @@ func Test_getPipelineWithFallback(t *testing.T) {
 			branch: "main",
 			setupMocks: func(tc *gitlabtesting.TestClient) {
 				tc.MockPipelines.EXPECT().
-					GetLatestPipeline("OWNER/REPO", &gitlab.GetLatestPipelineOptions{Ref: gitlab.Ptr("main")}).
+					GetLatestPipeline("OWNER/REPO", &gitlab.GetLatestPipelineOptions{Ref: gitlab.Ptr("main")}, gomock.Any()).
 					Return(&gitlab.Pipeline{ID: 1, Status: "success"}, nil, nil)
+
+				// Mock job check to verify pipeline has jobs
+				tc.MockJobs.EXPECT().
+					ListPipelineJobs("OWNER/REPO", int64(1), gomock.Any(), gomock.Any()).
+					Return([]*gitlab.Job{{ID: 1, Name: "test"}}, nil, nil)
 			},
 			wantPipeline: &gitlab.Pipeline{ID: 1, Status: "success"},
 			wantErr:      false,
 		},
+		{
+			name:   "falls back to MR pipeline when branch pipeline has no jobs",
+			branch: "feature",
+			setupMocks: func(tc *gitlabtesting.TestClient) {
+				// Latest pipeline found but has no jobs (e.g., external pipeline)
+				tc.MockPipelines.EXPECT().
+					GetLatestPipeline("OWNER/REPO", &gitlab.GetLatestPipelineOptions{Ref: gitlab.Ptr("feature")}, gomock.Any()).
+					Return(&gitlab.Pipeline{ID: 1, Status: "success"}, nil, nil)
+
+				// Mock job check returns empty list
+				tc.MockJobs.EXPECT().
+					ListPipelineJobs("OWNER/REPO", int64(1), gomock.Any(), gomock.Any()).
+					Return([]*gitlab.Job{}, nil, nil)
+
+				// Find and get MR
+				tc.MockMergeRequests.EXPECT().
+					ListProjectMergeRequests("OWNER/REPO", gomock.Any()).
+					Return([]*gitlab.BasicMergeRequest{{IID: 1}}, nil, nil)
+
+				tc.MockMergeRequests.EXPECT().
+					GetMergeRequest("OWNER/REPO", int64(1), gomock.Any()).
+					Return(&gitlab.MergeRequest{
+						BasicMergeRequest: gitlab.BasicMergeRequest{IID: 1},
+						HeadPipeline:      &gitlab.Pipeline{ID: 2, Status: "running"},
+					}, nil, nil)
+
+				tc.MockPipelines.EXPECT().
+					GetPipeline("OWNER/REPO", int64(2), gomock.Any()).
+					Return(&gitlab.Pipeline{
+						ID:     2,
+						Status: "running",
+					}, nil, nil)
+			},
+			wantPipeline: &gitlab.Pipeline{ID: 2, Status: "running"},
+			wantErr:      false,
+		},
 		{
 			name:   "falls back to MR pipeline when latest not found",
 			branch: "feature",
 			setupMocks: func(tc *gitlabtesting.TestClient) {
 				// Latest pipeline not found
 				tc.MockPipelines.EXPECT().
-					GetLatestPipeline("OWNER/REPO", &gitlab.GetLatestPipelineOptions{Ref: gitlab.Ptr("feature")}).
+					GetLatestPipeline("OWNER/REPO", &gitlab.GetLatestPipelineOptions{Ref: gitlab.Ptr("feature")}, gomock.Any()).
 					Return(nil, nil, errors.New("not found"))
 
 				// Find and get MR
@@ -49,14 +93,14 @@ func Test_getPipelineWithFallback(t *testing.T) {
 					Return([]*gitlab.BasicMergeRequest{{IID: 1}}, nil, nil)
 
 				tc.MockMergeRequests.EXPECT().
-					GetMergeRequest("OWNER/REPO", 1, gomock.Any()).
+					GetMergeRequest("OWNER/REPO", int64(1), gomock.Any()).
 					Return(&gitlab.MergeRequest{
 						BasicMergeRequest: gitlab.BasicMergeRequest{IID: 1},
 						HeadPipeline:      &gitlab.Pipeline{ID: 2, Status: "running"},
 					}, nil, nil)
 
 				tc.MockPipelines.EXPECT().
-					GetPipeline("OWNER/REPO", 2, gomock.Any()).
+					GetPipeline("OWNER/REPO", int64(2), gomock.Any()).
 					Return(&gitlab.Pipeline{
 						ID:     2,
 						Status: "running",
@@ -71,7 +115,7 @@ func Test_getPipelineWithFallback(t *testing.T) {
 			setupMocks: func(tc *gitlabtesting.TestClient) {
 				// Latest pipeline not found
 				tc.MockPipelines.EXPECT().
-					GetLatestPipeline("OWNER/REPO", &gitlab.GetLatestPipelineOptions{Ref: gitlab.Ptr("feature")}).
+					GetLatestPipeline("OWNER/REPO", &gitlab.GetLatestPipelineOptions{Ref: gitlab.Ptr("feature")}, gomock.Any()).
 					Return(nil, nil, errors.New("not found"))
 
 				// No MRs found
@@ -81,7 +125,7 @@ func Test_getPipelineWithFallback(t *testing.T) {
 			},
 			wantPipeline:   nil,
 			wantErr:        true,
-			expectedErrMsg: "no pipeline found for branch feature and no associated merge request found",
+			expectedErrMsg: "no pipeline found for branch feature and failed to find associated merge request",
 		},
 		{
 			name:   "returns error when MR has no pipeline",
@@ -89,7 +133,7 @@ func Test_getPipelineWithFallback(t *testing.T) {
 			setupMocks: func(tc *gitlabtesting.TestClient) {
 				// Latest pipeline not found
 				tc.MockPipelines.EXPECT().
-					GetLatestPipeline("OWNER/REPO", &gitlab.GetLatestPipelineOptions{Ref: gitlab.Ptr("feature")}).
+					GetLatestPipeline("OWNER/REPO", &gitlab.GetLatestPipelineOptions{Ref: gitlab.Ptr("feature")}, gomock.Any()).
 					Return(nil, nil, errors.New("not found"))
 
 				// Find MR but no pipeline
@@ -97,7 +141,7 @@ func Test_getPipelineWithFallback(t *testing.T) {
 					ListProjectMergeRequests("OWNER/REPO", gomock.Any()).
 					Return([]*gitlab.BasicMergeRequest{{IID: 1}}, nil, nil)
 				tc.MockMergeRequests.EXPECT().
-					GetMergeRequest("OWNER/REPO", 1, gomock.Any()).
+					GetMergeRequest("OWNER/REPO", int64(1), gomock.Any()).
 					Return(&gitlab.MergeRequest{
 						BasicMergeRequest: gitlab.BasicMergeRequest{IID: 1},
 					}, nil, nil)
@@ -113,11 +157,10 @@ func Test_getPipelineWithFallback(t *testing.T) {
 			tc := gitlabtesting.NewTestClient(t)
 			tt.setupMocks(tc)
 
-			// Create a test factory with test IO streams
+			// Create test IO streams
 			ios, _, _, _ := cmdtest.TestIOStreams(cmdtest.WithTestIOStreamsAsTTY(false))
-			factory := cmdtest.NewTestFactory(ios, cmdtest.WithGitLabClient(tc.Client))
 
-			pipeline, err := getPipelineWithFallback(tc.Client, factory, "OWNER/REPO", tt.branch)
+			pipeline, err := ciutils.GetPipelineWithFallback(t.Context(), tc.Client, "OWNER/REPO", tt.branch, ios)
 
 			if tt.wantErr {
 				assert.Error(t, err)
@@ -144,12 +187,17 @@ func TestCiStatusCommand_NoPrompt(t *testing.T) {
 	gomock.InOrder(
 		// Mock a finished pipeline so the command doesn't loop
 		tc.MockPipelines.EXPECT().
-			GetLatestPipeline("OWNER/REPO", &gitlab.GetLatestPipelineOptions{Ref: gitlab.Ptr("main")}).
+			GetLatestPipeline("OWNER/REPO", &gitlab.GetLatestPipelineOptions{Ref: gitlab.Ptr("main")}, gomock.Any()).
 			Return(&gitlab.Pipeline{ID: 1, Status: "success"}, nil, nil),
 
+		// Mock job check in GetPipelineWithFallback
+		tc.MockJobs.EXPECT().
+			ListPipelineJobs("OWNER/REPO", int64(1), gomock.Any()).
+			Return([]*gitlab.Job{{ID: 1, Name: "test"}}, nil, nil),
+
 		// Mock jobs for the pipeline - need to handle pagination
 		tc.MockJobs.EXPECT().
-			ListPipelineJobs("OWNER/REPO", 1, gomock.Any(), gomock.Any()).
+			ListPipelineJobs("OWNER/REPO", int64(1), gomock.Any(), gomock.Any()).
 			Return([]*gitlab.Job{
 				{ID: 1, Name: "test", Stage: "test", Status: "success"},
 			}, &gitlab.Response{NextPage: 0}, nil),
@@ -178,12 +226,17 @@ func TestCiStatusCommand_WithPromptsEnabled_FinishedPipeline(t *testing.T) {
 	gomock.InOrder(
 		// Mock a finished pipeline
 		tc.MockPipelines.EXPECT().
-			GetLatestPipeline("OWNER/REPO", &gitlab.GetLatestPipelineOptions{Ref: gitlab.Ptr("main")}).
+			GetLatestPipeline("OWNER/REPO", &gitlab.GetLatestPipelineOptions{Ref: gitlab.Ptr("main")}, gomock.Any()).
 			Return(&gitlab.Pipeline{ID: 1, Status: "success"}, nil, nil),
 
+		// Mock job check in GetPipelineWithFallback
+		tc.MockJobs.EXPECT().
+			ListPipelineJobs("OWNER/REPO", int64(1), gomock.Any()).
+			Return([]*gitlab.Job{{ID: 1, Name: "test"}}, nil, nil),
+
 		// Mock jobs for the pipeline - need to handle pagination
 		tc.MockJobs.EXPECT().
-			ListPipelineJobs("OWNER/REPO", 1, gomock.Any(), gomock.Any()).
+			ListPipelineJobs("OWNER/REPO", int64(1), gomock.Any(), gomock.Any()).
 			Return([]*gitlab.Job{
 				{ID: 1, Name: "test", Stage: "test", Status: "success"},
 			}, &gitlab.Response{NextPage: 0}, nil),
