@@ -15,7 +15,6 @@ import (
 	gitlabtesting "gitlab.com/gitlab-org/api/client-go/testing"
 
 	"gitlab.com/gitlab-org/cli/internal/testing/cmdtest"
-	"gitlab.com/gitlab-org/cli/test"
 )
 
 const (
@@ -323,7 +322,11 @@ func Test_SecurefileDownload(t *testing.T) {
 			testClient := gitlabtesting.NewTestClient(t)
 			tc.setupMocks(testClient)
 
-			out, err := runCommand(testClient, tc.cli)
+			exec := cmdtest.SetupCmdForTest(t, NewCmdDownload, false,
+				cmdtest.WithGitLabClient(testClient.Client),
+			)
+			out, err := exec(tc.cli)
+
 			if tc.wantErr {
 				if assert.Error(t, err) {
 					require.Equal(t, tc.wantStderr, err.Error())
@@ -605,7 +608,11 @@ func Test_SecurefileDownloadAll(t *testing.T) {
 			testClient := gitlabtesting.NewTestClient(t)
 			tc.setupMocks(testClient)
 
-			out, err := runCommand(testClient, tc.cli)
+			exec := cmdtest.SetupCmdForTest(t, NewCmdDownload, false,
+				cmdtest.WithGitLabClient(testClient.Client),
+			)
+			out, err := exec(tc.cli)
+
 			if tc.wantErr {
 				if assert.Error(t, err) {
 					require.Equal(t, tc.wantStderr, err.Error())
@@ -646,12 +653,3 @@ func TestEnsureDirectoryExists_InvalidDirectory(t *testing.T) {
 	require.Error(t, err)
 	assert.Contains(t, err.Error(), "error creating directory")
 }
-
-func runCommand(testClient *gitlabtesting.TestClient, cli string) (*test.CmdOut, error) {
-	ios, _, stdout, stderr := cmdtest.TestIOStreams()
-	factory := cmdtest.NewTestFactory(ios,
-		cmdtest.WithGitLabClient(testClient.Client),
-	)
-	cmd := NewCmdDownload(factory)
-	return cmdtest.ExecuteCommand(cmd, cli, stdout, stderr)
-}
